@@ -81,6 +81,34 @@ class TkeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def AddNodeToNodePool(self, request):
+        """This API is used to move nodes in a cluster to a node pool.
+
+        :param request: Request instance for AddNodeToNodePool.
+        :type request: :class:`tencentcloud.tke.v20180525.models.AddNodeToNodePoolRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.AddNodeToNodePoolResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("AddNodeToNodePool", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.AddNodeToNodePoolResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateCluster(self, request):
         """This API is used to create a cluster.
 
@@ -221,6 +249,62 @@ class TkeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateClusterNodePool(self, request):
+        """This API is used to create a node pool.
+
+        :param request: Request instance for CreateClusterNodePool.
+        :type request: :class:`tencentcloud.tke.v20180525.models.CreateClusterNodePoolRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.CreateClusterNodePoolResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateClusterNodePool", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateClusterNodePoolResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CreateClusterNodePoolFromExistingAsg(self, request):
+        """This API is used to upgrade a scaling group to a node pool.
+
+        :param request: Request instance for CreateClusterNodePoolFromExistingAsg.
+        :type request: :class:`tencentcloud.tke.v20180525.models.CreateClusterNodePoolFromExistingAsgRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.CreateClusterNodePoolFromExistingAsgResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateClusterNodePoolFromExistingAsg", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateClusterNodePoolFromExistingAsgResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateClusterRouteTable(self, request):
         """This API is used to create a cluster route table.
 
@@ -389,6 +473,34 @@ class TkeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteClusterNodePool(self, request):
+        """This API is used to delete a node pool.
+
+        :param request: Request instance for DeleteClusterNodePool.
+        :type request: :class:`tencentcloud.tke.v20180525.models.DeleteClusterNodePoolRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.DeleteClusterNodePoolResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteClusterNodePool", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteClusterNodePoolResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteClusterRoute(self, request):
         """This API is used to delete a cluster route.
 
@@ -613,6 +725,62 @@ class TkeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeClusterNodePoolDetail(self, request):
+        """This API is used to query detailed information of a node pool.
+
+        :param request: Request instance for DescribeClusterNodePoolDetail.
+        :type request: :class:`tencentcloud.tke.v20180525.models.DescribeClusterNodePoolDetailRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.DescribeClusterNodePoolDetailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeClusterNodePoolDetail", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeClusterNodePoolDetailResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeClusterNodePools(self, request):
+        """This API is used to query the node pool list
+
+        :param request: Request instance for DescribeClusterNodePools.
+        :type request: :class:`tencentcloud.tke.v20180525.models.DescribeClusterNodePoolsRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.DescribeClusterNodePoolsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeClusterNodePools", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeClusterNodePoolsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeClusterRouteTables(self, request):
         """This API is used to query one or more cluster route tables.
 
@@ -914,6 +1082,62 @@ class TkeClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ModifyClusterNodePool(self, request):
+        """This API is used to edit a node pool.
+
+        :param request: Request instance for ModifyClusterNodePool.
+        :type request: :class:`tencentcloud.tke.v20180525.models.ModifyClusterNodePoolRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.ModifyClusterNodePoolResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyClusterNodePool", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyClusterNodePoolResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def RemoveNodeFromNodePool(self, request):
+        """This API is used to remove a node from a node pool but retain it in the cluster.
+
+        :param request: Request instance for RemoveNodeFromNodePool.
+        :type request: :class:`tencentcloud.tke.v20180525.models.RemoveNodeFromNodePoolRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.RemoveNodeFromNodePoolResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("RemoveNodeFromNodePool", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.RemoveNodeFromNodePoolResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
